package Sah::Schemas::Binary;

1;
# ABSTRACT: Sah schemas related to binary data

__END__

=pod

=encoding UTF-8

=head1 NAME

Sah::Schemas::Binary - Sah schemas related to binary data

=head1 VERSION

This document describes version 0.004 of Sah::Schemas::Binary (from Perl distribution Sah-Schemas-Binary), released on 2020-03-04.

=head1 SAH SCHEMAS

=over

=item * L<hexbuf|Sah::Schema::hexbuf>

Binary data encoded in hexdigits.

=back

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Binary>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Sah-Schemas-Binary>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Sah-Schemas-Binary>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 SEE ALSO

L<Sah> - specification

L<Data::Sah>

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2020, 2018 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
